==> hoteldruid-mod-de_1.3.2-1.tar.gz: de/inizio.php <==
<?php

switch ($messaggio) {

case "Menù principale dell'anno":                               $messaggio = "Hauptmen&uuml; f&uuml;r das Jahr"; break;
case "Inserisci una nuova prenotazione":                         $messaggio = "Neue Reservierung eingeben"; break;
case "prenotazioni del mese di":                                 $messaggio = "Reservierungen ab"; break;
case "visualizza":                                               $messaggio = "anzeigen"; break;
case "Gennaio":                                                  $messaggio = "Januar"; break;
case "Febbraio":                                                 $messaggio = "Februar"; break;
case "Marzo":                                                    $messaggio = "M&auml;rz"; break;
case "Aprile":                                                   $messaggio = "April"; break;
case "Maggio":                                                   $messaggio = "Mai"; break;
case "Giugno":                                                   $messaggio = "Juni"; break;
case "Luglio":                                                   $messaggio = "Juli"; break;
case "Agosto":                                                   $messaggio = "August"; break;
case "Settembre":                                                $messaggio = "September"; break;
case "Ottobre":                                                  $messaggio = "Oktober"; break;
case "Novembre":                                                 $messaggio = "November"; break;
case "Dicembre":                                                 $messaggio = "Dezember"; break;
case "tabella con":                                              $messaggio = "&Uuml;bersicht mit"; break;
case "tutte le prenotazioni":                                    $messaggio = "allen Reservierungen"; break;
case "le spese e le entrate":                                    $messaggio = "Einnahmen und Ausgaben"; break;
case "i periodi e le tariffe":                                   $messaggio = "den Zeitr&auml;umen und Preisen"; break;
case "tutti i clienti":                                          $messaggio = "allen Kunden"; break;
case "le regole di assegnazione":                                $messaggio = "den Zuweisungsregeln"; break;
case "Inserisci un nuovo cliente":                               $messaggio = "Einen neuen Kunden einf&uuml;gen"; break;
case "Spese ed entrate":                                         $messaggio = "Ein- und Auszahlungen"; break;
case "disponibilità dal":                                       $messaggio = "Reservierung ab"; break;
case "al":                                                       $messaggio = "bis"; break;
case "per":                                                      $messaggio = "f&uuml;r"; break;
case "persone":                                                  $messaggio = "Personen"; break;
case "controlla":                                                $messaggio = "pr&uuml;fen"; break;
case "Inserisci o modifica i prezzi":                            $messaggio = "Eingeben oder &auml;ndern von Preisen"; break;
case "Inserisci o modifica le regole di assegnazione":           $messaggio = "Eingeben oder &auml;ndern von Zuweisungsregeln"; break;
case "Configura e personalizza":                                 $messaggio = "Konfigurieren und anpassen"; break;
case "richiedi l'anno":                                          $messaggio = "das Jahr"; break;
case "vai":                                                      $messaggio = "&ouml;ffnen"; break;
case "Non esiste l'anno ":                                       $messaggio = "Das Jahr "; break;
case " nel database":                                            $messaggio = "existiert nicht in der Datenbank"; break;
case "Crea l'anno":                                              $messaggio = "Erzeuge das Jahr"; break;
case "Domenica":                                                 $messaggio = "Sonntag"; break;
case "Lunedì":                                                  $messaggio = "Montag"; break;
case "Martedì":                                                 $messaggio = "Dienstag"; break;
case "Mercoledì":                                               $messaggio = "Mittwoch"; break;
case "Giovedì":                                                 $messaggio = "Donnerstag"; break;
case "Venerdì":                                                 $messaggio = "Freitag"; break;
case "Sabato":                                                   $messaggio = "Samstag"; break;
case "come giorno di inizio/fine locazione":                     $messaggio = "als Tag f&uuml;r Anfang/Ende der Miete"; break;
case "con periodi":                                              $messaggio = "mit"; break;
case "settimanali":                                              $messaggio = "w&ouml;chentlichen Zeitr&auml;umen"; break;
case "giornalieri":                                              $messaggio = "t&auml;glichen Zeitr&auml;umen"; break;
case "e prenotazioni da":                                        $messaggio = "und Reservierungen von"; break;
case "a":                                                        $messaggio = "bis"; break;
case "anno successivo":                                          $messaggio = "nchstes Jahr"; break;
case "anni successivi":                                          $messaggio = "Folgejahre"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Importiere vom Vorjahr die Reservierungen, Preise (inklusive Aufschl&auml;ge) und Zuweisungsregeln die auf dieses Jahr verweisen."; break;
case "Anno ":                                                    $messaggio = "Jahr "; break;
case " creato":                                                  $messaggio = " erstellt"; break;
case "Non ci sono periodi che riguardano il ":                   $messaggio = "Es gibt keinen Zeitraum bez&uuml;glich "; break;
case " nel ":                                                    $messaggio = " in "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":        $messaggio = ", oder der Anfangs-/Endtag war unterschiedlich, nur Daten &uuml;ber Aufschl&auml;ge, Anzahlungen, Namen der Preise und die Zuweisungsregeln 2 und 3 wurden importiert."; break;
case "Attenzione</b></font>: i periodi del ":                    $messaggio = "Achtung</b></font>: die Zeitr&auml;ume von "; break;
case " finivano dopo quelli del ":                               $messaggio = " enden nach denen von "; break;
case " e vi erano":                                              $messaggio = " und da waren"; break;
case "prenotazioni che finivano dopo il limite posto al ":       $messaggio = "Reservierungen die Enden nach dem Limit das gesetzt wurde f&uuml;r "; break;
case ", queste prenotazioni non sono state importate":           $messaggio = ", diese Reservierungen wurden nicht importiert"; break;
case "Anno già creato":                                         $messaggio = "Jahr wurde bereits erstellt"; break;
case " Do":                                                      $messaggio = " So"; break;
case " Lu":                                                      $messaggio = " Mo"; break;
case " Ma":                                                      $messaggio = " Di"; break;
case " Me":                                                      $messaggio = " Mi"; break;
case " Gi":                                                      $messaggio = " Do"; break;
case " Ve":                                                      $messaggio = " Fr"; break;
case " Sa":                                                      $messaggio = " Sa"; break;
case "Gen":                                                      $messaggio = "Jan"; break;
case "Feb":                                                      $messaggio = "Feb"; break;
case "Mar":                                                      $messaggio = "M&auml;r"; break;
case "Apr":                                                      $messaggio = "Apr"; break;
case "Mag":                                                      $messaggio = "Mai"; break;
case "Giu":                                                      $messaggio = "Jun"; break;
case "Lug":                                                      $messaggio = "Jul"; break;
case "Ago":                                                      $messaggio = "Aug"; break;
case "Set":                                                      $messaggio = "Sep"; break;
case "Ott":                                                      $messaggio = "Okt"; break;
case "Nov":                                                      $messaggio = "Nov"; break;
case "Dic":                                                      $messaggio = "Dez"; break;
case "Il formato dell'anno richiesto è sbagliato":              $messaggio = "Das Format des gew&uuml;nschten Jahres ist falsch"; break;
case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":        $messaggio = "Monate wurden falsch ausgew&auml;hlt, sie wurden von J&auml;nner bis Dezember eingetragen."; break;
case "N&deg;":                                                   $messaggio = "N&deg;"; break;
case "Cognome del cliente":                                      $messaggio = "Nachname des Kunden"; break;
case "Data iniziale":                                            $messaggio = "Startdatum"; break;
case "Data finale":                                              $messaggio = "Enddatum"; break;
case "Tariffa completa":                                         $messaggio = "Vollst&auml;ndiger Tarif"; break;
case "Da pagare":                                                $messaggio = "Zu zahlen"; break;
case "Pers":                                                     $messaggio = "Pers"; break;
case "Registra":                                                 $messaggio = "Anmelden"; break;
case "Entrata":                                                  $messaggio = "Ankunft"; break;
case "Uscita":                                                   $messaggio = "Abfahrt"; break;
case "Entrata e pagato":                                         $messaggio = "Eingetroffen und bezahlt"; break;
case "Uscita e pagato":                                          $messaggio = "Abgereist und bezahlt"; break;
case "mostra tutte le date":                                     $messaggio = "Alle Daten anzeigen"; break;
case "Utente":                                                   $messaggio = "Nutzer"; break;
case "Esci":                                                     $messaggio = "Abmelden"; break;
case "Messaggi":                                                 $messaggio = "Mitteilungen"; break;
case "<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al":                 $messaggio = "<span class=\"colred\">Hinweis</span>: Sie werden gebeten zu warten"; break;
case "per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il":           $messaggio = "vor der Einrichtung des neuen Jahres knnen sie einzelne Perioden erstellen"; break;
case "dalla":                                                    $messaggio = "vom"; break;
case "tabella con i periodi e le tariffe":                       $messaggio = "Tabelle mit Zeitr&auml;umen und Tarifen"; break;
case "anche senza creare un nuovo anno":                         $messaggio = "ohne Erstellung des neuen Jahres"; break;
case "Non ho i permessi di scrittura sulla cartella dati":       $messaggio = "Es sind keine Schreibrechte im Datenverzeichnis (dati)"; break;
case "le statistiche":                                           $messaggio = "die Auswertungen"; break;
case "inventario e magazzini":                                   $messaggio = "Inventur und Lagerrume"; break;
case "obsoleti":                                                 $messaggio = "berlagert"; break;
case "Ultimo aggiornamento":                                     $messaggio = "Letzte Korrektur"; break;
case "Aggiorna":                                                 $messaggio = "Korrektur"; break;
case "i documenti salvati":                                      $messaggio = "gesicherte Dokumente"; break;
case "Punto vendita":                                            $messaggio = "POS"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-de_2.1.2-1.tar.gz: de/inizio.php <==
<?php

switch ($messaggio) {

case "Menù principale dell'anno":                               $messaggio = "Hauptmen&uuml; f&uuml;r das Jahr"; break;
case "Inserisci una nuova prenotazione":                         $messaggio = "Neue Reservierung eingeben"; break;
case "prenotazioni del mese di":                                 $messaggio = "Reservierungen ab"; break;
case "visualizza":                                               $messaggio = "anzeigen"; break;
case "Gennaio":                                                  $messaggio = "Januar"; break;
case "Febbraio":                                                 $messaggio = "Februar"; break;
case "Marzo":                                                    $messaggio = "M&auml;rz"; break;
case "Maggio":                                                   $messaggio = "Mai"; break;
case "Giugno":                                                   $messaggio = "Juni"; break;
case "Luglio":                                                   $messaggio = "Juli"; break;
case "Ottobre":                                                  $messaggio = "Oktober"; break;
case "Dicembre":                                                 $messaggio = "Dezember"; break;
case "tabella con":                                              $messaggio = "&Uuml;bersicht mit"; break;
case "tutte le prenotazioni":                                    $messaggio = "allen Reservierungen"; break;
case "le spese e le entrate":                                    $messaggio = "Einnahmen und Ausgaben"; break;
case "i periodi e le tariffe":                                   $messaggio = "den Zeitr&auml;umen und Preisen"; break;
case "tutti i clienti":                                          $messaggio = "allen Kunden"; break;
case "le regole di assegnazione":                                $messaggio = "den Zuweisungsregeln"; break;
case "Inserisci un nuovo cliente":                               $messaggio = "Einen neuen Kunden einf&uuml;gen"; break;
case "Spese ed entrate":                                         $messaggio = "Ein- und Auszahlungen"; break;
case "disponibilità dal":                                       $messaggio = "Reservierung ab"; break;
case "al":                                                       $messaggio = "bis"; break;
case "per":                                                      $messaggio = "f&uuml;r"; break;
case "persone":                                                  $messaggio = "Personen"; break;
case "controlla":                                                $messaggio = "pr&uuml;fen"; break;
case "Inserisci o modifica i prezzi":                            $messaggio = "Eingeben oder &auml;ndern von Preisen"; break;
case "Inserisci o modifica le regole di assegnazione":           $messaggio = "Eingeben oder &auml;ndern von Zuweisungsregeln"; break;
case "Configura e personalizza":                                 $messaggio = "Konfigurieren und anpassen"; break;
case "richiedi l'anno":                                          $messaggio = "das Jahr"; break;
case "vai":                                                      $messaggio = "&ouml;ffnen"; break;
case "Non esiste l'anno ":                                       $messaggio = "Das Jahr "; break;
case " nel database":                                            $messaggio = "existiert nicht in der Datenbank"; break;
case "Crea l'anno":                                              $messaggio = "Erzeuge das Jahr"; break;
case "Domenica":                                                 $messaggio = "Sonntag"; break;
case "Lunedì":                                                  $messaggio = "Montag"; break;
case "Martedì":                                                 $messaggio = "Dienstag"; break;
case "Mercoledì":                                               $messaggio = "Mittwoch"; break;
case "Giovedì":                                                 $messaggio = "Donnerstag"; break;
case "Venerdì":                                                 $messaggio = "Freitag"; break;
case "Sabato":                                                   $messaggio = "Samstag"; break;
case "come giorno di inizio/fine locazione":                     $messaggio = "als Tag f&uuml;r Anfang/Ende der Miete"; break;
case "con periodi":                                              $messaggio = "mit"; break;
case "settimanali":                                              $messaggio = "w&ouml;chentlichen Zeitr&auml;umen"; break;
case "giornalieri":                                              $messaggio = "t&auml;glichen Zeitr&auml;umen"; break;
case "e prenotazioni da":                                        $messaggio = "und Reservierungen von"; break;
case "a":                                                        $messaggio = "bis"; break;
case "anno successivo":                                          $messaggio = "nchstes Jahr"; break;
case "anni successivi":                                          $messaggio = "Folgejahre"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Importiere vom Vorjahr die Reservierungen, Preise (inklusive Aufschl&auml;ge) und Zuweisungsregeln die auf dieses Jahr verweisen."; break;
case "Anno ":                                                    $messaggio = "Jahr "; break;
case " creato":                                                  $messaggio = " erstellt"; break;
case "Non ci sono periodi che riguardano il ":                   $messaggio = "Es gibt keinen Zeitraum bez&uuml;glich "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":        $messaggio = ", oder der Anfangs-/Endtag war unterschiedlich, nur Daten &uuml;ber Aufschl&auml;ge, Anzahlungen, Namen der Preise und die Zuweisungsregeln 2 und 3 wurden importiert."; break;
case "Attenzione</b></font>: i periodi del ":                    $messaggio = "Achtung</b></font>: die Zeitr&auml;ume von "; break;
case " finivano dopo quelli del ":                               $messaggio = " enden nach denen von "; break;
case " e vi erano":                                              $messaggio = " und da waren"; break;
case "prenotazioni che finivano dopo il limite posto al ":       $messaggio = "Reservierungen die Enden nach dem Limit das gesetzt wurde f&uuml;r "; break;
case ", queste prenotazioni non sono state importate":           $messaggio = ", diese Reservierungen wurden nicht importiert"; break;
case "Anno già creato":                                         $messaggio = "Jahr wurde bereits erstellt"; break;
case " Do":                                                      $messaggio = " So"; break;
case " Lu":                                                      $messaggio = " Mo"; break;
case " Ma":                                                      $messaggio = " Di"; break;
case " Me":                                                      $messaggio = " Mi"; break;
case " Gi":                                                      $messaggio = " Do"; break;
case " Ve":                                                      $messaggio = " Fr"; break;
case " Sa":                                                      $messaggio = " Sa"; break;
case "Gen":                                                      $messaggio = "Jan"; break;
case "Feb":                                                      $messaggio = "Feb"; break;
case "Mar":                                                      $messaggio = "M&auml;r"; break;
case "Apr":                                                      $messaggio = "Apr"; break;
case "Mag":                                                      $messaggio = "Mai"; break;
case "Giu":                                                      $messaggio = "Jun"; break;
case "Lug":                                                      $messaggio = "Jul"; break;
case "Ago":                                                      $messaggio = "Aug"; break;
case "Set":                                                      $messaggio = "Sep"; break;
case "Ott":                                                      $messaggio = "Okt"; break;
case "Nov":                                                      $messaggio = "Nov"; break;
case "Dic":                                                      $messaggio = "Dez"; break;
case "Il formato dell'anno richiesto è sbagliato":              $messaggio = "Das Format des gew&uuml;nschten Jahres ist falsch"; break;
case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":        $messaggio = "Monate wurden falsch ausgew&auml;hlt, sie wurden von J&auml;nner bis Dezember eingetragen."; break;
case "Cognome del cliente":                                      $messaggio = "Nachname des Kunden"; break;
case "Data iniziale":                                            $messaggio = "Startdatum"; break;
case "Data finale":                                              $messaggio = "Enddatum"; break;
case "Tariffa completa":                                         $messaggio = "Vollst&auml;ndiger Tarif"; break;
case "Da pagare":                                                $messaggio = "Zu zahlen"; break;
case "Pers":                                                     $messaggio = "Pers"; break;
case "Registra":                                                 $messaggio = "Anmelden"; break;
case "Entrata":                                                  $messaggio = "Ankunft"; break;
case "Uscita":                                                   $messaggio = "Abfahrt"; break;
case "Entrata e pagato":                                         $messaggio = "Eingetroffen und bezahlt"; break;
case "Uscita e pagato":                                          $messaggio = "Abgereist und bezahlt"; break;
case "mostra tutte le date":                                     $messaggio = "Alle Daten anzeigen"; break;
case "Utente":                                                   $messaggio = "Nutzer"; break;
case "Esci":                                                     $messaggio = "Abmelden"; break;
case "Messaggi":                                                 $messaggio = "Mitteilungen"; break;
case "<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al":                 $messaggio = "<span class=\"colred\">Hinweis</span>: Sie werden gebeten zu warten"; break;
case "per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il":           $messaggio = "vor der Einrichtung des neuen Jahres knnen sie einzelne Perioden erstellen"; break;
case "dalla":                                                    $messaggio = "vom"; break;
case "tabella con i periodi e le tariffe":                       $messaggio = "Tabelle mit Zeitr&auml;umen und Tarifen"; break;
case "anche senza creare un nuovo anno":                         $messaggio = "ohne Erstellung des neuen Jahres"; break;
case "Non ho i permessi di scrittura sulla cartella dati":       $messaggio = "Es sind keine Schreibrechte im Datenverzeichnis (dati)"; break;
case "le statistiche":                                           $messaggio = "die Auswertungen"; break;
case "inventario e magazzini":                                   $messaggio = "Inventar und Lagerr&auml;ume"; break;
case "obsoleti":                                                 $messaggio = "Veraltet"; break;
case "Ultimo aggiornamento":                                     $messaggio = "Letzte Korrektur"; break;
case "Aggiorna":                                                 $messaggio = "Korrektur"; break;
case "i documenti salvati":                                      $messaggio = "gesicherte Dokumente"; break;
case "Punto vendita":                                            $messaggio = "POS"; break;
case "Aprile":      				$messaggio = "April"; break;
case "Agosto":  				$messaggio = "August"; break;
case "Settembre":  				$messaggio = "September"; break;
case "Novembre":  				$messaggio = "November"; break;
case " nel ":  					$messaggio = " in "; break;
case "N&deg;":  				$messaggio = "N&deg;"; break;
case "Non ho i permessi per creare nuove tabelle nel database":	$messaggio = "I don't have permissions to create new tables in the database"; break;
case "Benvenuto a HOTELDRUID":  		$messaggio = "Welcome to HOTELDRUID"; break;
case "Scegli la lingua":  			$messaggio = "Choose the language"; break;
case "crea il database":  			$messaggio = "create database"; break;
case "Promemoria":  				$messaggio = "Reminder"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
